@@ -1,7 +1,7 @@
 #
 # segatex SELinux tool.
 #
-# Copyright (C) 2007-2008 Shintaro Fujiwara 
+# Copyright (C) 2007-2013 Shintaro Fujiwara 
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -218,5 +218,9 @@ do
 done
 
 echo "Breaking .if scripts Successfully finished."
+echo ""
+echo "You can see raw .if files in /usr/share/segatex/raw_if_files/"layers" as if_raw files."
+echo "You can understand fully the meaning of interfaces of SELinx."
+
 
 exit $ERROR
