@@ -174,7 +174,7 @@
 	createStatusBar();
 	updateMenus();
 	readSettings();
-	setWindowTitle(tr("segatex-7.830"));
+	setWindowTitle(tr("segatex-7.860"));
 	QPixmap myIcon1 = QPixmap(":/images/icon.png");
 	this->setIcon(myIcon1);
 }
@@ -625,7 +625,7 @@ void MainWindow::paste()
 void MainWindow::about()
 {
 	QMessageBox::about(this, tr("About segatex"),
-		tr("<h2>segatex-7.830</h2>"
+		tr("<h2>segatex-7.860</h2>"
 		"<p>Copyright &copy; 2007-2013"
 		"<p>Shintaro Fujiwara."
 		"<p>segatex is a SELinux tool"
@@ -1153,27 +1153,44 @@ void MainWindow::howtouse()
 {
 	QMessageBox::about(this, tr("How to use"),
 		tr("<h2>How to use segatex</h2>"
-		"<p><font color=\"blue\">[segatex]</font>"
+		"<p><font color=\"blue\">[segatex]</font></p>"
 		"<p>You can set selinux enforcing"
 		" and permissive just pushing button."
-		" You can install/update SELinux related"
-		" RPMs.You can audit2allow"
+		"<br />"
+		" You can install/update SELinux related RPMs."
+		"<br />"
+		"You can audit2allow."
+		"<br />"
 		" You can analize audit log."
+		"<br />"
 		" You can manage modules."
+		"<br />"
 		" You can semanage."
+		"<br />"
 		" You can setsebool."
+		"<br />"
 		" You can relabel the system."
+		"<br />"
 		" You can generate brand-new policy module."
+		"<br />"
 		" You can generate interfaced policy,by "
-		" Analize audit.log-generate policy."
+		" analize audit.log-generate policy."
+		"<br />"
 		" You can aureport."
+		"<br />"
 		" You can ausearch."
+		"<br />"
 		" You can restorecon."
+		"<br />"
 		" You can add/delete Linux user."
-		" You can ftp download."
+		"<br />"
+		" You can ftp download brand new Fedora iso files."
+		"<br />"
 		" You can analyze refpolicy."
-		"<p><font color=\"blue\">[segatex_editor]</font>"
-		"<p>Push break .te or .if"
+		"<br />"
+		"<p><font color=\"blue\">[segatex_editor]</font></p>"
+		"<p>Push break .te or .if</p>"
+		"<p>Looking into raw .te or .if files will help you understand type enforcement or refpolicy interfaces.</p>"
 		""));
 }
 void MainWindow::enforcing()
